@@ -16,6 +16,10 @@ fit2 <- glm(y ~ x, family = binomial)
 comp <- anova(fit1, fit2, test = "Chisq")
 plotchisqtest(comp)
 
+## -----------------------------------------------------------------------------
+mod <- glm(y ~ x, family = binomial)
+plotchisqtest(mod)
+
 ## -----------------------------------------------------------------------------
 plotftest(f = 4, dfnum = 3, dfdenom = 5)
 
